.. _user_guide:

************
User's Guide
************

Welcome to the user guide for ``btrack``.

.. toctree::
   :maxdepth: 2

   installation
   simple_example
   configuration
   using_features
   napari
   saving_tracks
   large_datasets
..
   Add other stuff
